==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_soapcastle_puuroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")RoomInit()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")RoomInit()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")RoomInit()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")RoomInit()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")RoomInit()FAI(4)
end

function RoomInit()
    LAY("fbk",true);
end

function GoSoapCastle()
    PRI()FAO(1)TRA("CS_soapcastle","E0093",22,38)
end

function Tank1()
    PRI()
    MS3("一个被打开的大型红色颜料罐，")NOD()
    CAT("\n颜料还是湿的，")NOD()
    CAT("\n表示刚刚才被使用过。")NOD()
end

function IronheadDyed()
    KEY()
    ANP("Ironhead1","lie")
    ANP("Tala1","look_down")
    FAI(2)
    WAI(64)
    FAC("puu_normal")MS3("\n那么我们开始吧。")NOD()CLR()
    FAC("soapwalker_normal")CAT("\n好嘞！")NOD()CLO()
    WAI(16)
    ANP("Puu1","back")
    ANP("Tala1","back")
    WAI(32)
    ANP("Ironhead1","struggle")
    WAI(64)
    ANP("Ironhead1","lie")
    WAI(64)
    ANP("Puu1","show_brush")
    ANP("Ironhead1","lie_dyed")
    WAI(32)
    ANP("Ironhead1","struggle_dyed")
    WAI(32)
    FAC("puu_dyed_normal")MS3("别动你这个蠢鱼！")NOD()
    CAT("\n颜料都渐我脸上了！！")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle","PlayedIronDyedAniEnd",22,38)
end

function TheKingIsComeBack()
    KEY()
    LAY("fbk",true);
    ANP("Ironhead1","red_lie")
    ANP("Puu1","back")
    ANP("Puu1","show_brush")
    ANP("Tala1","back")
    FAI(2)
    WAI(64)
    SOU("CS_026_quake")QUA(16)
    WAI(16)
    ANP("Puu1","normal")
    WAI(16)
    ANP("Tala1","normal")
    WAI(16)
    FAC("puu_normal")MS3("糟了！")
    CAT("\n是巨魔兄弟们的信号。")NOD()CLR()
    CAT("\n\"大王回来了！\"")NOD()CLR()
    ANP("Tala1","look_down")
    FAC("soapwalker_normal")CAT("你接下来打算怎么办？")NOD()
    CAT("\n虽说是防水涂料，")NOD()
    CAT("\n但现在没干。")NOD()
    CAT("\n直接丢回到池子里的话")
    CAT("\n怕不是变成血池...")NOD()CLR()
    ANP("Puu1","normal",1)
    FAC("puu_normal")CAT("我去想办法拖住大王，")NOD()
    CAT("\n剩下的交给你了！")NOD()CLO()
    ANP("Puu1","leave")
    WAI(32)
    ANP("Tala1","look_normal")
    WAI(16)
    ANP("Tala1","look_up")
    WAI(32)
    ANP("Tala1","look_top")
    WAI(16)
    FAC("soapwalker_angry")MS3("\n喂！别把摊子全甩给我啊！")NOD()CLO()
    WAI(64)
    ANP("Tala1","look_down")
    WAI(64)
    ANP("Tala1","back")
    WAI(32)
    MS3("\n只能先把鱼抬到我房间想想办法了...")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_soapcastle_talaroom","DryIronhead",21,15)
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_soapcastle_puuroom.lua <==
function E0090()
    MNA()CMU("CS_Vivi")RoomInit()FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")RoomInit()FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")RoomInit()FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")RoomInit()FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")RoomInit()FAI(4)
end

function RoomInit()
    LAY("fbk",true);
end

function GoSoapCastle()
    PRI()FAO(1)TRA("CS_soapcastle","E0093",22,38)
end

function Tank1()
    if(FLJ("HeroBack")) then
        PRI()
        MS3("一个被打开的大型红色丙烯颜料罐，")NOD()
        CAT("\n颜料已经干了。")NOD()
    else
        PRI()
        MS3("一个被打开的大型红色颜料罐，")NOD()
        CAT("\n颜料还是湿的，")NOD()
        CAT("\n表示刚刚才被使用过。")NOD()
    end
end

function IronheadDyed()
    KEY()
    ANP("Ironhead1","lie")
    ANP("Tala1","look_down")
    FAI(2)
    WAI(64)
    FAC("puu_normal")MS3("\n那么我们开始吧。")NOD()CLR()
    FAC("soapwalker_normal")CAT("\n好嘞！")NOD()CLO()
    WAI(16)
    ANP("Puu1","back")
    ANP("Tala1","back")
    WAI(32)
    ANP("Ironhead1","struggle")
    WAI(64)
    ANP("Ironhead1","lie")
    WAI(64)
    ANP("Puu1","show_brush")
    ANP("Ironhead1","lie_dyed")
    WAI(32)
    ANP("Ironhead1","struggle_dyed")
    WAI(32)
    FAC("puu_dyed_normal")MS3("别动你这个蠢鱼！")NOD()
    CAT("\n颜料都溅我脸上了！！")NOD()CLO()
    FAO(0)
    TRA("CS_soapcastle","PlayedIronDyedAniEnd",22,38)
end

function TheKingIsComeBack()
    KEY()
    LAY("fbk",true);
    ANP("Ironhead1","red_lie")
    ANP("Puu1","back")
    ANP("Puu1","show_brush")
    ANP("Tala1","back")
    FAI(2)
    WAI(64)
    SOU("CS_026_quake")QUA(16)
    WAI(16)
    ANP("Puu1","normal")
    WAI(16)
    ANP("Tala1","normal")
    WAI(16)
    FAC("puu_normal")MS3("糟了！")
    CAT("\n是巨魔兄弟们的信号。")NOD()CLR()
    CAT("\n\"大王回来了！\"")NOD()CLR()
    ANP("Tala1","look_down")
    FAC("soapwalker_normal")CAT("你接下来打算怎么办？")NOD()
    CAT("\n虽说是防水涂料，")NOD()
    CAT("\n但现在没干。")NOD()
    CAT("\n直接丢回到池子里的话")
    CAT("\n怕不是变成血池...")NOD()CLR()
    ANP("Puu1","normal",1)
    FAC("puu_normal")CAT("我去想办法拖住大王，")NOD()
    CAT("\n剩下的交给你了！")NOD()CLO()
    ANP("Puu1","leave")
    WAI(32)
    ANP("Tala1","look_normal")
    WAI(16)
    ANP("Tala1","look_up")
    WAI(32)
    ANP("Tala1","look_top")
    WAI(16)
    FAC("soapwalker_angry")MS3("\n喂！别把摊子全甩给我啊！")NOD()CLO()
    WAI(64)
    ANP("Tala1","look_down")
    WAI(64)
    ANP("Tala1","back")
    WAI(32)
    MS3("\n只能先把鱼抬到我房间想想办法了...")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_soapcastle_talaroom","DryIronhead",21,15)
end
